@@ -56,10 +56,16 @@ class Cvt_Int(Cvt):
     cmd = "interface", None
 
     def remove(self, old, int_name):
-        # default the interface, if it's physical (as we can't remove
-        # physical interfaces)
+        # if the interface is physical, we can't delete it ...
         if is_int_physical(int_name):
-            return "default interface " + int_name
+            # ... but, if there was something in the old configuration
+            # other than just it being shut down, we 'default' it
+            if old.keys() != { "shutdown" }:
+                return "default interface " + int_name
+
+            # the only thing in the old configuration was that it was
+            # shutdown, so we ignore this
+            return
 
         return "no interface " + int_name
 
